# Fab Four Plots
# PSYC 4165
# Lew Harvey
# 13 January 2018

# Generic generic strip and box plot main effects functions

# df = data frame with data to be plotted
# dv = dependent variable column name
# iv1 = independent variable 1 column name (usually a condition)
# iv2 = independent variable 2 column name (usually the subject ID)
# use_mu = flag to compute mean value of dv for each level of iv1
#           and each level of iv2 across all remain independent variable levels
# colo = colors for plotting
# xlab = x-axis label for plot
# ylab = y-axis label for plot
# main = main title for plot

strip.main.effect <- function(df = NULL, dv = "?", iv1 = "?", iv2 = "subj",
                              use_mu = FALSE,
                              between = FALSE,
                              colo = "black",
                              xlab = "", ylab = "", main = "") {
    if (use_mu) {
        f <- formula(eval(parse(text=paste(dv, "~", iv1, "+", iv2))))
        tmp <- aggregate(f, data = df, FUN = mean)}
    else {tmp <- df}

    mef <- eval(parse(text=paste("tmp$", iv1, sep = "")))
    lvs <- levels(mef)
    nlv <- nlevels(mef)

    f <- formula(eval(parse(text=paste(dv, "~", iv1))))
    stripchart(f, data = tmp,
               vertical = TRUE,
               cex.axis = 0.65,
               col = colo,
               xlim = c(0.5, nlv + 0.5),
               xlab = xlab,
               ylab = ylab,
               main = main)

    # draw segments for within-subject points
    if (between == FALSE) {
        for (i in 1:(nlv - 1)){
            y0 <- tmp[mef == lvs[i],   dv]
            y1 <- tmp[mef == lvs[i+1], dv]
            segments(x0 = i,  y0 = y0, x1 = i + 1,  y1 = y1, col = "gray")
        }
    }
}

box.main.effect <- function(df = NULL, dv = "?", iv1 = "?", iv2 = "subj",
                            use_mu = FALSE,
                            colo = "yellow",
                            xlab = "", ylab = "", main = "") {
    if (use_mu) {
        f <- formula(eval(parse(text=paste(dv, "~", iv1, "+", iv2))))
        tmp <- aggregate(f, data = df, FUN = mean)}
    else {tmp <- df}

    mef <- eval(parse(text=paste("tmp$", iv1, sep = "")))
    lvs <- levels(mef)
    nlv <- nlevels(mef)

    f <- formula(eval(parse(text=paste(dv, "~", iv1))))
    boxplot(f, data = tmp,
            vertical = TRUE,
            col = colo,
            xlim = c(0.5, nlv + 0.5),
            cex.axis = 0.65,
            xlab = xlab,
            ylab = ylab,
            main = main)
}

# generic effect-size plot function
# bs = results object from bootES()
box.effect.size <- function(bs,
                            colo = "yellow",
                            xlab = "Main Effect",
                            ylab = "Effect Size",
                            main = "Title") {
    ymin <- min(0, min(bs$t))
    ymax <- max(0, max(bs$t))
    boxplot(bs$t, vertical = TRUE,
            col = colo,
            ylim = c(ymin, ymax),
            xlab = xlab,
            ylab = ylab,
            main = main)
    abline(h = 0, col = "red")
    abline(h = c(bs$t0, bs$bounds), col = "gray")
    text(0.65, c(bs$t0, bs$bounds), labels=c(paste(round(bs$t0, 2)), "lower CI", "upper CI"),
         cex=0.8, col="gray", pos=c(3, 1, 3))
}

